# Users’ attitude towards adding human feedback when preparing for quitting smoking/vaping with a virtual coach
This file provides information on how to reproduce our analyses for the paper "Users’ attitude towards adding human feedback when preparing for quitting smoking/vaping with a virtual coach: A mixed-methods analysis" by Yoan Naydenov.
Go to https://doi.org/10.17605/OSF.IO/78CNR to have a look at the original data used for this analysis.
**Author**: Yoan Naydenov \
**Date**: June 2024

## Contents of the repository
```
AnalysisData
│
└───Code
│   │   kappas.py
│   │   quantitative_analysis.py
│
└───Data
│   │   post_questionnaire_coder1.csv
│   │	post_questionnaire_coder2.xlsx
│
└───Results
│   │   Codes plus themes.pdf
│   │   correlation.xlsx
│   │   kappas.xlsx
|
│	README.md
|
```

## Data
All data has been anonymized and there is an identifier `rand_id` that is used to distinguish between people.

## Explanation of files and folders
- `kappas.py`: Python file containing the code to calculate the cohen's kappa, Brennan Prediger's kappa and number of occurrences of codes.
- `quantitative_analysis.py`: Python file containing the code to calculate the Spearman correlation coefficient and p-value.
- `post_questionnaire_coder1.csv`: CSV file containing the coding of the responses by the original coder.
- `post_questionnaire_coder2.xlsx`: Excel file containing the coding of the responses by the second coder.
- `README.md`: This file.
- `correlation.xlsx`: Excel file containing the calculated Spearman correlation coefficient and p-value for each theme with accordance to several variables.
- `kappas.xlsx`: Excel file containing the calculated Cohen's kappa of each code, the weighted average Cohen's kappa, Brennan Prediger's kappa and number of occurrences of codes.
- `themes.jpg`: Jpg file containing a thematic map linking all codes to their corresponding themes.

## Running the kappas.py 
1. Add the path to the coded responses by the first coder as first_coder_path.
2. Add the path to the coded responses by the second coder as second_coder_path.
3. Run the main method. 
4. Results are printed in the terminal.

## Running the quantitative_analysis.py 
1. Add the path to the file containing all variables wanted for correlation and codes as well as file_path.
2. Run the main method. 
3. Results are printed in the terminal.

## Tables explanation
- `kappas.xlsx`: sheet 1 - one table with the Cohen's kappa values for each code, one table with the number of occurrences of each code, one tables with the weighted average Cohen's kappa and one table with the Brennan Prediger's kappa values.
- `correlation.xlsx`: sheet 1 - Theme1 - two tables with Spearman correlation values and corresponding p-values calculated with relation to a subset of variables from the post-questionnaire with regards to the first theme found - emotional connection and support, a table containing contribution of the codes to the theme.
- `correlation.xlsx`: sheet 2 - Theme2 - two tables with Spearman correlation values and corresponding p-values calculated with relation to a subset of variables from the post-questionnaire with regards to the second theme found - personalization and expertise, a table containing contribution of the codes to the theme.
- `correlation.xlsx`: sheet 3 - Theme3 - two tables with Spearman correlation values and corresponding p-values calculated with relation to a subset of variables from the post-questionnaire with regards to the third theme found - effectiveness and engagement, a table containing contribution of the codes to the theme.
- `correlation.xlsx`: sheet 4 - Theme4 - two tables with Spearman correlation values and corresponding p-values calculated with relation to a subset of variables from the post-questionnaire with regards to the fourth theme found - motivation and encouragement, a table containing contribution of the codes to the theme.
- `correlation.xlsx`: sheet 5 - Theme5 - two tables with Spearman correlation values and corresponding p-values calculated with relation to a subset of variables from the post-questionnaire with regards to the fifth theme found - accountability, a table containing contribution of the codes to the theme.